@@ -203,7 +203,8 @@ extern unsigned  var_sendupdate(BtvarRef, BtvarRef, ShreqRef);
 extern vhash_t  myvariable(BtvarRef, BtmodeRef, const unsigned);
 extern vhash_t  vid_uplook(const vident *);
 extern char **envhandle(BtjobRef);
-extern struct remote *find_connected(const netid_t);
+extern struct remote *find_srv_connected(const netid_t);
+extern struct remote *find_cli_connected(const netid_t);
 extern struct remote *find_probe(const netid_t);
 extern struct remote *find_sync(const netid_t, const int);
 extern struct remote *alloc_roam(struct remote *);
